==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1RBDVolumeSourceFluentImpl.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import io.kubernetes.client.fluent.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

public class V1RBDVolumeSourceFluentImpl<A extends V1RBDVolumeSourceFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V1RBDVolumeSourceFluent<A>{

    private String fsType;
    private String image;
    private String keyring;
    private List<String> monitors;
    private String pool;
    private Boolean readOnly;
    private V1LocalObjectReferenceBuilder secretRef;
    private String user;

    public V1RBDVolumeSourceFluentImpl(){
    }
    public V1RBDVolumeSourceFluentImpl(V1RBDVolumeSource instance){
            this.withFsType(instance.getFsType());

            this.withImage(instance.getImage());

            this.withKeyring(instance.getKeyring());

            this.withMonitors(instance.getMonitors());

            this.withPool(instance.getPool());

            this.withReadOnly(instance.isReadOnly());

            this.withSecretRef(instance.getSecretRef());

            this.withUser(instance.getUser());

    }

    public String getFsType(){
            return this.fsType;
    }

    public A withFsType(String fsType){
            this.fsType=fsType; return (A) this;
    }

    public Boolean hasFsType(){
            return this.fsType != null;
    }

    public String getImage(){
            return this.image;
    }

    public A withImage(String image){
            this.image=image; return (A) this;
    }

    public Boolean hasImage(){
            return this.image != null;
    }

    public String getKeyring(){
            return this.keyring;
    }

    public A withKeyring(String keyring){
            this.keyring=keyring; return (A) this;
    }

    public Boolean hasKeyring(){
            return this.keyring != null;
    }

    public A addToMonitors(int index,String item){
            if (this.monitors == null) {this.monitors = new ArrayList<String>();}
            this.monitors.add(index, item);
            return (A)this;
    }

    public A setToMonitors(int index,String item){
            if (this.monitors == null) {this.monitors = new ArrayList<String>();}
            this.monitors.set(index, item); return (A)this;
    }

    public A addToMonitors(String... items){
            if (this.monitors == null) {this.monitors = new ArrayList<String>();}
            for (String item : items) {this.monitors.add(item);} return (A)this;
    }

    public A addAllToMonitors(Collection<String> items){
            if (this.monitors == null) {this.monitors = new ArrayList<String>();}
            for (String item : items) {this.monitors.add(item);} return (A)this;
    }

    public A removeFromMonitors(String... items){
            for (String item : items) {if (this.monitors!= null){ this.monitors.remove(item);}} return (A)this;
    }

    public A removeAllFromMonitors(Collection<String> items){
            for (String item : items) {if (this.monitors!= null){ this.monitors.remove(item);}} return (A)this;
    }

    public List<String> getMonitors(){
            return this.monitors;
    }

    public String getMonitor(int index){
            return this.monitors.get(index);
    }

    public String getFirstMonitor(){
            return this.monitors.get(0);
    }

    public String getLastMonitor(){
            return this.monitors.get(monitors.size() - 1);
    }

    public String getMatchingMonitor(io.kubernetes.client.fluent.Predicate<String> predicate){
            for (String item: monitors) { if(predicate.apply(item)){return item;} } return null;
    }

    public A withMonitors(List<String> monitors){
            if (this.monitors != null) { _visitables.removeAll(this.monitors);}
            if (monitors != null) {this.monitors = new ArrayList<String>(); for (String item : monitors){this.addToMonitors(item);}} else { this.monitors = null;} return (A) this;
    }

    public A withMonitors(String... monitors){
            if (this.monitors != null) {this.monitors.clear();}
            if (monitors != null) {for (String item :monitors){ this.addToMonitors(item);}} return (A) this;
    }

    public Boolean hasMonitors(){
            return monitors != null && !monitors.isEmpty();
    }

    public String getPool(){
            return this.pool;
    }

    public A withPool(String pool){
            this.pool=pool; return (A) this;
    }

    public Boolean hasPool(){
            return this.pool != null;
    }

    public Boolean isReadOnly(){
            return this.readOnly;
    }

    public A withReadOnly(Boolean readOnly){
            this.readOnly=readOnly; return (A) this;
    }

    public Boolean hasReadOnly(){
            return this.readOnly != null;
    }

    public A withNewReadOnly(boolean arg1){
            return (A)withReadOnly(new Boolean(arg1));
    }

    public A withNewReadOnly(String arg1){
            return (A)withReadOnly(new Boolean(arg1));
    }

    
/**
 * This method has been deprecated, please use method buildSecretRef instead.
 * @return The buildable object.
 */
@Deprecated public V1LocalObjectReference getSecretRef(){
            return this.secretRef!=null?this.secretRef.build():null;
    }

    public V1LocalObjectReference buildSecretRef(){
            return this.secretRef!=null?this.secretRef.build():null;
    }

    public A withSecretRef(V1LocalObjectReference secretRef){
            _visitables.remove(this.secretRef);
            if (secretRef!=null){ this.secretRef= new V1LocalObjectReferenceBuilder(secretRef); _visitables.add(this.secretRef);} return (A) this;
    }

    public Boolean hasSecretRef(){
            return this.secretRef != null;
    }

    public V1RBDVolumeSourceFluent.SecretRefNested<A> withNewSecretRef(){
            return new SecretRefNestedImpl();
    }

    public V1RBDVolumeSourceFluent.SecretRefNested<A> withNewSecretRefLike(V1LocalObjectReference item){
            return new SecretRefNestedImpl(item);
    }

    public V1RBDVolumeSourceFluent.SecretRefNested<A> editSecretRef(){
            return withNewSecretRefLike(getSecretRef());
    }

    public V1RBDVolumeSourceFluent.SecretRefNested<A> editOrNewSecretRef(){
            return withNewSecretRefLike(getSecretRef() != null ? getSecretRef(): new V1LocalObjectReferenceBuilder().build());
    }

    public V1RBDVolumeSourceFluent.SecretRefNested<A> editOrNewSecretRefLike(V1LocalObjectReference item){
            return withNewSecretRefLike(getSecretRef() != null ? getSecretRef(): item);
    }

    public String getUser(){
            return this.user;
    }

    public A withUser(String user){
            this.user=user; return (A) this;
    }

    public Boolean hasUser(){
            return this.user != null;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1RBDVolumeSourceFluentImpl that = (V1RBDVolumeSourceFluentImpl) o;
            if (fsType != null ? !fsType.equals(that.fsType) :that.fsType != null) return false;
            if (image != null ? !image.equals(that.image) :that.image != null) return false;
            if (keyring != null ? !keyring.equals(that.keyring) :that.keyring != null) return false;
            if (monitors != null ? !monitors.equals(that.monitors) :that.monitors != null) return false;
            if (pool != null ? !pool.equals(that.pool) :that.pool != null) return false;
            if (readOnly != null ? !readOnly.equals(that.readOnly) :that.readOnly != null) return false;
            if (secretRef != null ? !secretRef.equals(that.secretRef) :that.secretRef != null) return false;
            if (user != null ? !user.equals(that.user) :that.user != null) return false;
            return true;
    }


    public class SecretRefNestedImpl<N> extends V1LocalObjectReferenceFluentImpl<V1RBDVolumeSourceFluent.SecretRefNested<N>> implements V1RBDVolumeSourceFluent.SecretRefNested<N>,io.kubernetes.client.fluent.Nested<N>{

            private final V1LocalObjectReferenceBuilder builder;
    
            SecretRefNestedImpl(V1LocalObjectReference item){
                    this.builder = new V1LocalObjectReferenceBuilder(this, item);
            }
            SecretRefNestedImpl(){
                    this.builder = new V1LocalObjectReferenceBuilder(this);
            }
    
    public N and(){
            return (N) V1RBDVolumeSourceFluentImpl.this.withSecretRef(builder.build());
    }
    public N endSecretRef(){
            return and();
    }

}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1RBDVolumeSourceFluentImpl.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import io.kubernetes.client.fluent.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

public class V1RBDVolumeSourceFluentImpl<A extends V1RBDVolumeSourceFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V1RBDVolumeSourceFluent<A>{

    private String fsType;
    private String image;
    private String keyring;
    private List<String> monitors;
    private String pool;
    private Boolean readOnly;
    private V1LocalObjectReferenceBuilder secretRef;
    private String user;

    public V1RBDVolumeSourceFluentImpl(){
    }
    public V1RBDVolumeSourceFluentImpl(V1RBDVolumeSource instance){
            this.withFsType(instance.getFsType());

            this.withImage(instance.getImage());

            this.withKeyring(instance.getKeyring());

            this.withMonitors(instance.getMonitors());

            this.withPool(instance.getPool());

            this.withReadOnly(instance.isReadOnly());

            this.withSecretRef(instance.getSecretRef());

            this.withUser(instance.getUser());

    }

    public String getFsType(){
            return this.fsType;
    }

    public A withFsType(String fsType){
            this.fsType=fsType; return (A) this;
    }

    public Boolean hasFsType(){
            return this.fsType != null;
    }

    public A withNewFsType(String arg1){
            return (A)withFsType(new String(arg1));
    }

    public A withNewFsType(StringBuilder arg1){
            return (A)withFsType(new String(arg1));
    }

    public A withNewFsType(StringBuffer arg1){
            return (A)withFsType(new String(arg1));
    }

    public String getImage(){
            return this.image;
    }

    public A withImage(String image){
            this.image=image; return (A) this;
    }

    public Boolean hasImage(){
            return this.image != null;
    }

    public A withNewImage(String arg1){
            return (A)withImage(new String(arg1));
    }

    public A withNewImage(StringBuilder arg1){
            return (A)withImage(new String(arg1));
    }

    public A withNewImage(StringBuffer arg1){
            return (A)withImage(new String(arg1));
    }

    public String getKeyring(){
            return this.keyring;
    }

    public A withKeyring(String keyring){
            this.keyring=keyring; return (A) this;
    }

    public Boolean hasKeyring(){
            return this.keyring != null;
    }

    public A withNewKeyring(String arg1){
            return (A)withKeyring(new String(arg1));
    }

    public A withNewKeyring(StringBuilder arg1){
            return (A)withKeyring(new String(arg1));
    }

    public A withNewKeyring(StringBuffer arg1){
            return (A)withKeyring(new String(arg1));
    }

    public A addToMonitors(int index,String item){
            if (this.monitors == null) {this.monitors = new ArrayList<String>();}
            this.monitors.add(index, item);
            return (A)this;
    }

    public A setToMonitors(int index,String item){
            if (this.monitors == null) {this.monitors = new ArrayList<String>();}
            this.monitors.set(index, item); return (A)this;
    }

    public A addToMonitors(String... items){
            if (this.monitors == null) {this.monitors = new ArrayList<String>();}
            for (String item : items) {this.monitors.add(item);} return (A)this;
    }

    public A addAllToMonitors(Collection<String> items){
            if (this.monitors == null) {this.monitors = new ArrayList<String>();}
            for (String item : items) {this.monitors.add(item);} return (A)this;
    }

    public A removeFromMonitors(String... items){
            for (String item : items) {if (this.monitors!= null){ this.monitors.remove(item);}} return (A)this;
    }

    public A removeAllFromMonitors(Collection<String> items){
            for (String item : items) {if (this.monitors!= null){ this.monitors.remove(item);}} return (A)this;
    }

    public List<String> getMonitors(){
            return this.monitors;
    }

    public String getMonitor(int index){
            return this.monitors.get(index);
    }

    public String getFirstMonitor(){
            return this.monitors.get(0);
    }

    public String getLastMonitor(){
            return this.monitors.get(monitors.size() - 1);
    }

    public String getMatchingMonitor(io.kubernetes.client.fluent.Predicate<String> predicate){
            for (String item: monitors) { if(predicate.apply(item)){return item;} } return null;
    }

    public Boolean hasMatchingMonitor(io.kubernetes.client.fluent.Predicate<String> predicate){
            for (String item: monitors) { if(predicate.apply(item)){return true;} } return false;
    }

    public A withMonitors(List<String> monitors){
            if (this.monitors != null) { _visitables.get("monitors").removeAll(this.monitors);}
            if (monitors != null) {this.monitors = new ArrayList<String>(); for (String item : monitors){this.addToMonitors(item);}} else { this.monitors = null;} return (A) this;
    }

    public A withMonitors(String... monitors){
            if (this.monitors != null) {this.monitors.clear();}
            if (monitors != null) {for (String item :monitors){ this.addToMonitors(item);}} return (A) this;
    }

    public Boolean hasMonitors(){
            return monitors != null && !monitors.isEmpty();
    }

    public A addNewMonitor(String arg1){
            return (A)addToMonitors(new String(arg1));
    }

    public A addNewMonitor(StringBuilder arg1){
            return (A)addToMonitors(new String(arg1));
    }

    public A addNewMonitor(StringBuffer arg1){
            return (A)addToMonitors(new String(arg1));
    }

    public String getPool(){
            return this.pool;
    }

    public A withPool(String pool){
            this.pool=pool; return (A) this;
    }

    public Boolean hasPool(){
            return this.pool != null;
    }

    public A withNewPool(String arg1){
            return (A)withPool(new String(arg1));
    }

    public A withNewPool(StringBuilder arg1){
            return (A)withPool(new String(arg1));
    }

    public A withNewPool(StringBuffer arg1){
            return (A)withPool(new String(arg1));
    }

    public Boolean isReadOnly(){
            return this.readOnly;
    }

    public A withReadOnly(Boolean readOnly){
            this.readOnly=readOnly; return (A) this;
    }

    public Boolean hasReadOnly(){
            return this.readOnly != null;
    }

    public A withNewReadOnly(String arg1){
            return (A)withReadOnly(new Boolean(arg1));
    }

    public A withNewReadOnly(boolean arg1){
            return (A)withReadOnly(new Boolean(arg1));
    }

    
/**
 * This method has been deprecated, please use method buildSecretRef instead.
 * @return The buildable object.
 */
@Deprecated public V1LocalObjectReference getSecretRef(){
            return this.secretRef!=null?this.secretRef.build():null;
    }

    public V1LocalObjectReference buildSecretRef(){
            return this.secretRef!=null?this.secretRef.build():null;
    }

    public A withSecretRef(V1LocalObjectReference secretRef){
            _visitables.get("secretRef").remove(this.secretRef);
            if (secretRef!=null){ this.secretRef= new V1LocalObjectReferenceBuilder(secretRef); _visitables.get("secretRef").add(this.secretRef);} return (A) this;
    }

    public Boolean hasSecretRef(){
            return this.secretRef != null;
    }

    public V1RBDVolumeSourceFluent.SecretRefNested<A> withNewSecretRef(){
            return new SecretRefNestedImpl();
    }

    public V1RBDVolumeSourceFluent.SecretRefNested<A> withNewSecretRefLike(V1LocalObjectReference item){
            return new SecretRefNestedImpl(item);
    }

    public V1RBDVolumeSourceFluent.SecretRefNested<A> editSecretRef(){
            return withNewSecretRefLike(getSecretRef());
    }

    public V1RBDVolumeSourceFluent.SecretRefNested<A> editOrNewSecretRef(){
            return withNewSecretRefLike(getSecretRef() != null ? getSecretRef(): new V1LocalObjectReferenceBuilder().build());
    }

    public V1RBDVolumeSourceFluent.SecretRefNested<A> editOrNewSecretRefLike(V1LocalObjectReference item){
            return withNewSecretRefLike(getSecretRef() != null ? getSecretRef(): item);
    }

    public String getUser(){
            return this.user;
    }

    public A withUser(String user){
            this.user=user; return (A) this;
    }

    public Boolean hasUser(){
            return this.user != null;
    }

    public A withNewUser(String arg1){
            return (A)withUser(new String(arg1));
    }

    public A withNewUser(StringBuilder arg1){
            return (A)withUser(new String(arg1));
    }

    public A withNewUser(StringBuffer arg1){
            return (A)withUser(new String(arg1));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1RBDVolumeSourceFluentImpl that = (V1RBDVolumeSourceFluentImpl) o;
            if (fsType != null ? !fsType.equals(that.fsType) :that.fsType != null) return false;
            if (image != null ? !image.equals(that.image) :that.image != null) return false;
            if (keyring != null ? !keyring.equals(that.keyring) :that.keyring != null) return false;
            if (monitors != null ? !monitors.equals(that.monitors) :that.monitors != null) return false;
            if (pool != null ? !pool.equals(that.pool) :that.pool != null) return false;
            if (readOnly != null ? !readOnly.equals(that.readOnly) :that.readOnly != null) return false;
            if (secretRef != null ? !secretRef.equals(that.secretRef) :that.secretRef != null) return false;
            if (user != null ? !user.equals(that.user) :that.user != null) return false;
            return true;
    }


    public class SecretRefNestedImpl<N> extends V1LocalObjectReferenceFluentImpl<V1RBDVolumeSourceFluent.SecretRefNested<N>> implements V1RBDVolumeSourceFluent.SecretRefNested<N>,io.kubernetes.client.fluent.Nested<N>{

            private final V1LocalObjectReferenceBuilder builder;
    
            SecretRefNestedImpl(V1LocalObjectReference item){
                    this.builder = new V1LocalObjectReferenceBuilder(this, item);
            }
            SecretRefNestedImpl(){
                    this.builder = new V1LocalObjectReferenceBuilder(this);
            }
    
    public N and(){
            return (N) V1RBDVolumeSourceFluentImpl.this.withSecretRef(builder.build());
    }
    public N endSecretRef(){
            return and();
    }

}


}
